window push version 11
window push set more on
window push log using 7.6.Framingham.ClassVersion.log, replace
window push *  7.6.Framingham.ClassVersion.log    
window push *
window push *  Proportional hazards regression analysis of the effect of gender and 
window push *  baseline diastolic blood pressure (DBP) on coronary heart disease (CHD)
window push *  adjusted for age, body mass index (BMI) and serum cholesterol (SCL).
window push *  
window push use C:\WDDtext\2.20.Framingham.dta, clear
window push *
window push *  Univariate analysis of the effect of DBP on CHD
window push *
window push histogram dbp, bin(50) frequency ylabel(0(100)500, angle(0)) ytick(0(50)500) ///
window push     xlabel(40(20)140) xtick(40(10)140) ytitle("Number of Study Subjects")
window push more
window push generate dbpgr = recode(dbp,60,70,80,90,100,110,111)
window push tabulate dbpgr chdfate
window push label define dbp 60  "DBP <=  60"      70  "60 < DBP <= 70"         ///
window push 		 90  "80 < DBP <= 90"  80  "70 < DBP <= 80"	    ///
window push 		 100 "90 < DBP <= 100" 110 "100 < DBP <= 110" 111 "110 < DBP"
window push label variable dbpgr "DBP level" 
window push label values dbpgr dbp
window push generate time= followup/365.25
window push label variable time "Follow-up in Years"
window push stset time, failure(chdfate)
window push sts graph, by(dbpgr) ytitle(Proportion Without CHD)  			///
window push    ylabel(0(.2)1, angle(0)) ytick(.0(.1)1) xlabel(0(5)30)	     	/// 
window push    xtitle("Years of Follow-up") legend(ring(0) position(7) col(1))  	
window push more
window push sts test dbpgr
window push sts test dbpgr if dbpgr ==  60 | dbpgr == 70
window push sts test dbpgr if dbpgr ==  70 | dbpgr == 80
window push sts test dbpgr if dbpgr ==  80 | dbpgr == 90
window push sts test dbpgr if dbpgr ==  90 | dbpgr == 100
window push sts test dbpgr if dbpgr == 100 | dbpgr == 110
window push sts test dbpgr if dbpgr == 110 | dbpgr == 111
window push stcox  i.dbpgr
window push *
window push *  Univariate analysis of the effect of gender on CHD
window push *
window push sts graph, by(sex) plot1opts(color(blue) lwidth(medthick) )  	///
window push    plot2opts(color(pink)  lwidth(medthick) )  			///
window push    ytitle(Cumulative CHD Morbidity)  				///
window push    xtitle("Years of Follow-up") xlabel(0(5)30) failure		///
window push    ylabel(0(.1).5, angle(0)) legend(ring(0) position(11) col(1))
window push more
window push sts test sex
window push codebook sex
window push generate male = sex==1
window push tabulate male sex
window push stcox male
window push *
window push *  To simplify the analyses let us use fewer DBP groups
window push *
window push generate dbpg2 = recode(dbp,60,90,110,111)
window push tabulate dbpg2
window push stcox  i.dbpg2
window push *
window push *  Store estimates from this model for future likelihood ratio 
window push *  tests (tests of change in model deviance).
window push *
window push estimates store _dbpg2
window push *
window push *   How do gender and baseline DBP affect CHD?
window push *
window push sort sex
window push by sex: tabulate dbpg2 chdfate ,row	
window push *
window push *  Fit multiplicative model of DBP and gender on risk of CHD
window push *
window push stcox  i.dbpg2 male
window push display 2*(11740.729   -11672.032)
window push display chi2tail(1, 137.394)
window push lrtest _dbpg2 .
window push more
window push estimates store dbp_male
window push 
window push lincom 90.dbpg2 + male , hr
window push lincom 110.dbpg2 + male , hr
window push lincom 111.dbpg2 + male , hr
window push 
window push *
window push *  Fit model of DBP and gender on risk of CHD using interaction terms
window push *
window push stcox  dbpg2##male
window push lrtest dbp_male .
window push estimates store dbp_maleInteract
window push lincom 90.dbpg2  + 1.male +  90.dbpg2#1.male, hr
window push lincom 110.dbpg2 + 1.male + 110.dbpg2#1.male, hr
window push lincom 111.dbpg2 + 1.male + 111.dbpg2#1.male, hr
window push *
window push *  Adjust model for age, BMI and SCL
window push *
window push stcox  dbpg2##male age 
window push lrtest dbp_maleInteract .
window push stcox  dbpg2##male age if !missing(bmi) & !missing(scl)
window push estimates store dbp_maleInteract_age
window push stcox  dbpg2##male age bmi scl 
window push lrtest dbp_maleInteract_age .
window push lincom  90.dbpg2  + 1.male +  90.dbpg2#1.male,  hr
window push lincom  110.dbpg2 + 1.male + 110.dbpg2#1.male, hr
window push lincom  111.dbpg2 + 1.male + 111.dbpg2#1.male, hr
window push log close



























