window push version 11.0
window push log using 8.9.Framingham.log, replace
window push *  8.9.Framingham.log 
window push *
window push *  Convert Framingham survival data setset to person-year data for 
window push *  Poisson regression analysis.
window push *
window push set more on
window push use  C:\WDDtext\2.20.Framingham.dta, clear
window push *
window push *  Convert bmi, scl and dbp into categorical variables that subdivide
window push *  the data set into quartiles for each of these variables.
window push *
window push centile bmi dbp scl, centile(25,50,75)
window push generate bmi_gr = recode(bmi, 22.8, 25.2, 28, 29)
window push generate dbp_gr = recode(dbp, 74,80,90,91)
window push generate scl_gr = recode(scl, 197, 225, 255, 256)
window push *
window push *  Calculate years of follow-up for each patient.
window push *  Round to nearest year for censored patients.
window push *  Round up to next year when patients exit with CHD
window push *
window push generate years = int(followup/365.25) + 1 if chdfate
window push replace years = round(followup/365.25, 1) if ~chdfate
window push table sex dbp_gr, contents(sum years) row col
window push table sex dbp_gr, contents(sum chdfate) row col
window push generate age_in = age
window push generate exit = age + years
window push summarize age_in exit
window push more
window push *
window push *  Transform data set so that there is one record per patient-year of 
window push *  follow-up.  Define age_now to be the patient's age in each record.
window push *
window push stset exit, id(id) enter(time age_in) failure(chdfate)
window push stsplit age_now, at(30(1)94)
window push list id age_in years exit age_now  in 278/282
window push generate age_gr = recode(age_now, 45,50,55,60,65,70,75,80,81)
window push label define age 45 "<= 45" 50 "45-50" 55 "50-55" 60 "55-60" 65 ///
window push     "60-65" 70 "65-70" 75 "70-75" 80 "75-80" 81 "> 80"
window push label values age_gr age
window push sort sex bmi_gr scl_gr dbp_gr age_gr
window push *
window push *  Combine records with identical values of 
window push *  sex bmi_gr scl_gr dbp_gr and age_gr.
window push *
window push collapse (count) pt_yrs=age_in (sum) chd_cnt=chdfate, by(sex bmi_gr scl_gr dbp_gr age_gr)
window push list sex bmi_gr scl_gr dbp_gr age_gr pt_yrs chd_cnt in 310/315, nodisplay
window push table sex dbp_gr, contents(sum pt_yrs) row col
window push table sex dbp_gr, contents(sum chd_cnt) row col
window push generate male = sex == 1
window push display _N
window push save  8.12.Framingham.dta, replace
window push log close











