window push version 11
window push set more on
window push log using 9.3.Framingham.log, replace
window push *  9.3.Framingham.log
window push *
window push *  Estimate the effect of age and gender on coronary heart disease (CHD)
window push *  using several Poisson regression models
window push *
window push use  8.12.Framingham.dta, clear
window push *
window push *  Fit a multiplicative model of the effect of gender and age on CHD
window push *
window push glm chd_cnt  i.age_gr male, family(poisson) link(log) 		 ///
window push     lnoffset(pt_yrs) eform
window push *
window push *  Tabulate patient-years of follow-up and number of
window push *  CHD events by sex and age group.
window push *
window push table sex, contents(sum pt_yrs sum chd_cnt) by(age_gr)
window push *
window push *  Calculate age-sex specific incidence of CHD
window push *
window push collapse (sum) patients = pt_yrs chd = chd_cnt, by(age_gr male)
window push generate rate = 1000*chd/patients
window push generate men = rate if male == 1
window push generate women = rate if male == 0
window push graph bar men women, over(age_gr) ytitle(CHD Morbidity Rate per 1000) 	 ///
window push     ylabel(0(5)40, angle(0)) subtitle(Age, position(6))                  ///
window push     legend(order(1 "Men" 2 "Women") ring(0) position(11) col(1))
window push more
window push use  8.12.Framingham.dta, clear
window push *
window push *  Add interaction terms to the model
window push *
window push glm chd_cnt age_gr##male, family(poisson) link(log) lnoffset(pt_yrs)
window push lincom 1.male, irr
window push lincom 1.male + 50.age_gr#1.male, irr
window push lincom 1.male + 55.age_gr#1.male, irr
window push lincom 1.male + 60.age_gr#1.male, irr
window push lincom 1.male + 65.age_gr#1.male, irr
window push lincom 1.male + 70.age_gr#1.male, irr
window push lincom 1.male + 75.age_gr#1.male, irr
window push lincom 1.male + 80.age_gr#1.male, irr
window push lincom 1.male + 81.age_gr#1.male, irr
window push display chi2tail(8, 1391.341888  - 1361.574107)
window push *
window push *  Refit model with interaction terms using fewer parameters.
window push *
window push generate age_gr2 = recode(age_gr, 45,55,60,80,81)
window push glm chd_cnt age_gr2##male 		 				 ///
window push     , family(poisson) link(log) lnoffset(pt_yrs) eform 
window push lincom 1.male + 55.age_gr2#1.male, irr
window push lincom 1.male + 60.age_gr2#1.male, irr
window push lincom 1.male + 80.age_gr2#1.male, irr
window push lincom 1.male + 81.age_gr2#1.male, irr
window push table bmi_gr
window push *
window push *  The i. syntax only works for integer variables.  bmi_gr gives the
window push *  quartile boundarys to one decimal place.  We multiply this variable
window push *  by 10 in order to be able to use this syntax.  Since indicator  
window push *  covariates are entered into the model, multiplying by 10 will  
window push *  not affect our estimates
window push *
window push gen bmi_gr10 = bmi_gr*10
window push *
window push *  Adjust analysis for body mass index (BMI)
window push *
window push glm chd_cnt age_gr2##male i.bmi_gr10	 				 ///
window push     , family(poisson) link(log) lnoffset(pt_yrs)
window push display chi2tail(3,1400.582451 - 1327.64597)
window push *
window push *  Adjust estimates for BMI and serum cholesterol
window push *
window push glm chd_cnt age_gr2##male i.bmi_gr10  i.scl_gr			 ///
window push     , family(poisson) link(log) lnoffset(pt_yrs) 
window push display chi2tail(3,1327.64597 - 1207.974985)
window push *
window push *  Adjust estimates for BMI, serum cholesterol and 
window push *  diastolic blood pressure
window push *
window push glm chd_cnt age_gr2##male i.bmi_gr10  i.scl_gr  i.dbp_gr		 ///
window push     , family(poisson) link(log) lnoffset(pt_yrs) eform
window push lincom 1.male + 55.age_gr2#1.male, irr
window push lincom 1.male + 60.age_gr2#1.male, irr
window push lincom 1.male + 80.age_gr2#1.male, irr
window push lincom 1.male + 81.age_gr2#1.male, irr
window push display chi2tail(3,1207.974985 - 1161.091086)
window push *
window push *  Compress data set for residual plot
window push *
window push sort male bmi_gr10 scl_gr dbp_gr age_gr2
window push collapse (sum) pt_yrs=pt_yrs chd_cnt=chd_cnt				 ///
window push     , by (male bmi_gr10 scl_gr dbp_gr age_gr2)
window push *
window push *  Re-analyze previous model using collapsed data set.
window push *
window push glm chd_cnt	age_gr2##male i.bmi_gr10  i.scl_gr  i.dbp_gr		 ///
window push     , family(poisson) link(log) lnoffset(pt_yrs)
window push *
window push *  Estimate the expected number of CHD events and the 
window push *  standardized deviance residual for each record in the data set.
window push *
window push predict e_chd, mu
window push predict dev, standardized deviance 
window push generate e_rate = 1000*e_chd/pt_yrs
window push label variable e_rate "Incidence of CHD per Thousand"
window push *
window push *  Draw scatterplot of the standardized deviance residual versus the 
window push *  estimated incidence of CHD.  Include lowess regression curve on this plot.
window push *
window push lowess dev e_rate, bwidth(0.2) msymbol(Oh) ylabel(-3(1)4) ytick(-3(0.5)4) ///
window push     lineopts(color(red) lwidth(medthick)) yline(-2 0 2, lcolor(blue))     ///
window push     xlabel(0(10)80) xtick(5(10)75)
window push log close

















