window push version 10.0
window push log using lymphoma.log, replace
window push *  Lymphoma.log
window push *
window push *  Plot Kaplan-Meier Survival curves of lymphoma patients by
window push *  stage of tumor. 
window push *
window push *  See Armitage and Berry, Table 14.3.
window push *      McKelvey et al., 1976.
window push *
window push set more on
window push use  lymphoma.dta, clear
window push list  in 1/7
window push codebook fate
window push stset time, failure (fate)
window push sts graph, by(stage) ytitle(Probability of Survival)
window push more
window push sts graph, by(stage) ytitle(Cumulative Mortality) failure
window push more
window push *
window push *  List survival statistics
window push *
window push sts list, by(stage)
window push sts list, by(stage) at (30 40 50)
window push sts list, by(stage) at (30 40 50) failure
window push label define stage 3 "Stage 3" 4 "Stage 4"
window push label values stage stage
window push *
window push *  Kaplan-Meier survival curves by stage with 95% CIs
window push *
window push sts graph, by(stage)   ci censored(single) separate 	///
window push     xlabel(0 (50) 350) xmtick(0 (25) 350)  		///
window push     byopts(title(, size(0)) legend(off))		///
window push     ytitle(Probability of Survival)               	///
window push     ylabel(0 (.1) 1, angle(0)) ciopts(color(yellow))    ///
window push     xtitle(Days Since Recruitment)  ymtick(0 (.05) 1)    
window push more
window push *
window push *  Kaplan-Meier morbidity curves by stage with risk table
window push *
window push sts graph, by(stage)  failure 				///
window push     risktable(,order(2 "Stage 4" 1 "Stage 3"))		///
window push     ytitle(Cumulative Mortality) 			///
window push     xlabel(0 (50) 350) xmtick(0 (25) 350)  		///
window push     ylabel(0 (.1) .8, angle(0)) 			///
window push     xtitle(Days Since Recruitment)  ymtick(0 (.05) .8) 	///
window push     title(" ",size(0)) legend(ring(0) cols(1) 		///
window push        position(11) order(2 "Stage 4" 1 "Stage 3")) 	 
window push 
window push *
window push *  Perform log-rank test to compare stage 3 and 4 survival
window push *
window push sts test stage
window push tabulate stage fate, exact
window push *
window push *  Perform proportional hazards regression analysis of
window push *  lymphoma patients by stage of tumor.
window push *
window push stcox stage
window push stcox stage, nohr
window push log close
