window push version 9.0
window push set more on
window push set scheme s2color
window push log using SUPPORTlogisticRCS.log, replace
window push * SUPPORTlogisticRC.log
window push *
window push *  Regress mortal status at discharge against MAP 
window push *  in the SUPPORT data set
window push *
window push set more on
window push use 3.25.2.SUPPORT.dta , replace
window push *
window push *  Calculate the proportion of patients who die in hospital
window push *   stratified by MAP.
window push *
window push generate map_gr = round(map,5)
window push sort map_gr
window push label variable map_gr "Mean Arterial Pressure (mm Hg)"
window push by map_gr: egen proportion = mean(fate)
window push generate rate = 100*proportion
window push label variable rate "Observed In-Hospital Mortality Rate (%)"
window push generate deaths = map_gr if fate
window push *
window push *  Draw an exploratory graph showing the number of patients, 
window push *  the number of deaths and the mortality rate for each MAP.
window push *
window push twoway histogram map_gr, discrete frequency color(gs13) gap(20) ///
window push     || histogram deaths, discrete frequency color(red) gap(20)	///
window push     || scatter rate map_gr, yaxis(2) symbol(Oh) color(blue)	///
window push     ,  xlabel(20 (20) 180) ylabel(0(10)100, angle(0))		///
window push        xmtick(25 (5) 175) ytitle(Number of Patients)		///
window push        ylabel(0 (10) 100, angle(0) labcolor(blue) axis(2)) 	///
window push        ytitle(,color(blue) axis(2))				///
window push        legend(order(1 "Total" 2 "Deaths" 3 "Mortality Rate" )	///
window push        rows(1)) name(g1) 
window push more
window push *
window push *  Regress in-hospital mortality against MAP using simple 
window push *  logistic regression.
window push *
window push logistic fate map
window push estimates store simple
window push predict p,p
window push label variable p "Probabilty of In-Hospital Death"
window push line p map, ylabel(0(.1)1, angle(0)) xlabel(20(20)180) name(g2)
window push more
window push drop p
window push *
window push *  Repeat the preceding model using restricted cubic splines 
window push *  with 5 knots at their default locations.
window push *
window push mkspline _Smap = map, cubic displayknots
window push logistic fate _S*
window push *
window push *  Test null hypotheses that the logit of the probability of
window push *  in-hospital death is a linear function of MAP.
window push *
window push lrtest simple .
window push display 2*(545.25721 -498.65571)
window push *
window push *  Plot the estimated probability of death against MAP together 
window push *  with the 95% confidence interval for this curve.  Overlay 
window push *  the MAP-specific observed mortality rates.
window push *
window push predict p,p
window push predict logodds, xb
window push predict stderr, stdp
window push generate p2 = exp(logodds)/(1+exp(logodds))
window push *
window push *  The values of p and p2 are identical
window push *
window push scatter p p2
window push generate lodds_lb = logodds - 1.96*stderr
window push generate lodds_ub = logodds + 1.96*stderr
window push generate ub_p= exp(lodds_ub)/(1+exp(lodds_ub))
window push generate lb_p= exp(lodds_lb)/(1+exp(lodds_lb))
window push twoway rarea lb_p ub_p map, color(yellow)				///
window push     || line p map, lwidth(medthick) color(red)				///
window push     || scatter proportion map_gr,  symbol(Oh) color(blue)		///
window push     ,  ylabel(0(.1)1, angle(0)) xlabel(20 (20) 180)  			///
window push        xmtick(25(5)175) ytitle(Probabilty of In-Hospital Death) 	///
window push        legend(order(3 "Observed" "Mortality" 2 "Expected" "Mortality" 	///
window push            1 "95% Confidence" "Interval") rows(1)) name(g3)
window push more
window push *
window push *  Determine the spline covariates at MAP = 90
window push *
window push list _S* if map == 90
window push *
window push *  Let or1 = _Smap1 minus the value of _Smap1 at 90.
window push *  Define or2, or3 and or3 in a similar fashion.
window push *
window push generate or1 = _Smap1 - 90
window push generate or2 = _Smap2 - 11.82436 
window push generate or3 = _Smap3 -  2.055919
window push generate or4 = _Smap4 -   .2569899
window push *
window push *  Calculate the log odds ratio for in-hospital death  
window push *  relative to patients with MAP = 90.
window push *
window push predictnl log_or = or1*_b[_Smap1] + or2*_b[_Smap2] ///
window push     + or3*_b[_Smap3] +or4*_b[_Smap4], se(se_or)
window push generate lb_log_or = log_or - 1.96*se_or
window push generate ub_log_or = log_or + 1.96*se_or
window push generate or = exp(log_or)
window push generate lb_or = exp(lb_log_or)
window push generate ub_or = exp(ub_log_or)
window push 
window push twoway rarea lb_or ub_or map, color(yellow)		 ///
window push     || line or map, lwidth(medthick) color(red)		 ///		
window push     ,  ylabel(1 (3) 10 40(30)100 400(300)1000, angle(0)) ///
window push        ymtick(2(1)10 20(10)100 200(100)900) yscale(log)  ///
window push        xlabel(20 (20) 180) xmtick(25 (5) 175) 		 ///
window push        ytitle(In-Hospital Mortal Odds Ratio)  		 ///
window push        legend(ring(0) position(2) order(2 "Odds Ratio" 	 ///
window push            1 "95% Confidence Interval") cols(1)) name(g4)
window push more
window push log close
